@@ -18,33 +18,50 @@ from cybrid_api_bank.model.bank import Bank
 from cybrid_api_bank.model.bank_list import BankList
 from cybrid_api_bank.model.customer import Customer
 from cybrid_api_bank.model.customer_list import CustomerList
+from cybrid_api_bank.model.deposit_address import DepositAddress
+from cybrid_api_bank.model.deposit_address_list import DepositAddressList
 from cybrid_api_bank.model.error_response import ErrorResponse
-from cybrid_api_bank.model.fee import Fee
-from cybrid_api_bank.model.fee_configuration import FeeConfiguration
-from cybrid_api_bank.model.fee_configuration_list import FeeConfigurationList
+from cybrid_api_bank.model.external_bank_account import ExternalBankAccount
+from cybrid_api_bank.model.external_bank_account_list import ExternalBankAccountList
 from cybrid_api_bank.model.identity_record import IdentityRecord
 from cybrid_api_bank.model.identity_record_list import IdentityRecordList
+from cybrid_api_bank.model.identity_verification import IdentityVerification
+from cybrid_api_bank.model.identity_verification_list import IdentityVerificationList
+from cybrid_api_bank.model.identity_verification_with_details import IdentityVerificationWithDetails
+from cybrid_api_bank.model.identity_verification_with_details_all_of import IdentityVerificationWithDetailsAllOf
 from cybrid_api_bank.model.list_request_page import ListRequestPage
 from cybrid_api_bank.model.list_request_per_page import ListRequestPerPage
 from cybrid_api_bank.model.patch_bank import PatchBank
+from cybrid_api_bank.model.patch_external_bank_account import PatchExternalBankAccount
 from cybrid_api_bank.model.post_account import PostAccount
 from cybrid_api_bank.model.post_bank import PostBank
 from cybrid_api_bank.model.post_customer import PostCustomer
-from cybrid_api_bank.model.post_fee import PostFee
-from cybrid_api_bank.model.post_fee_configuration import PostFeeConfiguration
+from cybrid_api_bank.model.post_deposit_address import PostDepositAddress
+from cybrid_api_bank.model.post_external_bank_account import PostExternalBankAccount
 from cybrid_api_bank.model.post_identity_record import PostIdentityRecord
 from cybrid_api_bank.model.post_identity_record_attestation_details import PostIdentityRecordAttestationDetails
+from cybrid_api_bank.model.post_identity_verification import PostIdentityVerification
+from cybrid_api_bank.model.post_one_time_address import PostOneTimeAddress
 from cybrid_api_bank.model.post_quote import PostQuote
 from cybrid_api_bank.model.post_reward import PostReward
 from cybrid_api_bank.model.post_trade import PostTrade
+from cybrid_api_bank.model.post_transfer import PostTransfer
 from cybrid_api_bank.model.post_verification_key import PostVerificationKey
+from cybrid_api_bank.model.post_workflow import PostWorkflow
 from cybrid_api_bank.model.quote import Quote
 from cybrid_api_bank.model.quote_list import QuoteList
 from cybrid_api_bank.model.reward import Reward
+from cybrid_api_bank.model.reward_list import RewardList
 from cybrid_api_bank.model.symbol_price import SymbolPrice
 from cybrid_api_bank.model.symbol_price_response import SymbolPriceResponse
 from cybrid_api_bank.model.symbols import Symbols
 from cybrid_api_bank.model.trade import Trade
 from cybrid_api_bank.model.trade_list import TradeList
+from cybrid_api_bank.model.transfer import Transfer
+from cybrid_api_bank.model.transfer_list import TransferList
 from cybrid_api_bank.model.verification_key import VerificationKey
 from cybrid_api_bank.model.verification_key_list import VerificationKeyList
+from cybrid_api_bank.model.workflow import Workflow
+from cybrid_api_bank.model.workflow_with_details import WorkflowWithDetails
+from cybrid_api_bank.model.workflow_with_details_all_of import WorkflowWithDetailsAllOf
+from cybrid_api_bank.model.workflows_list import WorkflowsList
